@@ -22,17 +22,19 @@ use Debconf::Client::ConfModule;
 
 =head1 NAME
 
-	DebAux::Debconf - easy interface to Debconf::Client::ConfModule
+  DebAux::Debconf - easy interface to Debconf::Client::ConfModule
 
 =head1 SYNOPSIS
 
-	use DebAux::Debconf;
-    DebAux::Util::get('package/name');
+  use DebAux::Debconf;
+  DebAux::Util::get('package/name');
+  DebAux::Util::set('package/name','value');
+  DebAux::Util::ask('medium','package/name');
 
 =head1 DESCRIPTION
 
-	This module provides an easy interface to Debconf::Client::Module
-	which does the error handling for you.
+  This module provides an easy interface to Debconf::Client::Module
+  which does the error handling for you.
 
 =head1 FUNCTIONS
 
@@ -40,7 +42,7 @@ use Debconf::Client::ConfModule;
 
 =item get I<name>
 
-	Get the value for I<name>. Dies on any error.
+  Get the value for I<name>. Dies on any error.
 
 =back
 
@@ -50,11 +52,55 @@ sub get {
 	my ($name) = @_;
 	my ($status, $value) = Debconf::Client::ConfModule::get($name);
 
-	if ($status && $status != 30) {
-		die ("Couldn't get debconf value for $name\n");
+	if ($status) {
+		die ("Couldn't get debconf value for $name (Status: $status)\n");
 	}
 
 	$value;
 }
 
+=over 4
+
+=item set I<name> I<value>
+
+  Set the value for I<name>. Dies on any error.
+
+=back
+
+=cut
+
+sub set {
+	my ($name, $value) = @_;
+	my $status = Debconf::Client::ConfModule::set($name, $value);
+
+	if ($status) {
+		die ("Couldn't set debconf value $value for $name (Status: $status)\n");
+	}
+
+	$value;
+}
+	
+=over 4
+
+=item ask I<priority> I<name>
+
+  Asks for the value for I<name> with the priority I<priority>.
+  Combines the debconf commands INPUT and GO.
+  Dies on any error.
+
+=back
+
+=cut
+
+sub ask {
+	my ($priority, $name) = @_;
+	my ($status, $value);
+
+	($status, $value) = Debconf::Client::ConfModule::input($priority, $name);
+	if ($status && $status != 30) {
+		die "Configuration of $name failed with status $status ($value)\n";
+	}
+	Debconf::Client::ConfModule::go();
+}
+
 1;
